==> croco_cli-0.3.0.tar.gz: croco_cli-0.3.0/README.md <==
# croco-cli

[![Croco Logo](https://i.ibb.co/G5Pjt6M/logo.png)](https://t.me/crocofactory) 

[![PyPi version](https://img.shields.io/pypi/v/croco-cli)](https://pypi.org/project/croco-cli/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/croco-cli)](https://pypi.org/project/croco-cli/)
[![License](https://img.shields.io/github/license/blnkoff/croco-cli.svg)](https://pypi.org/project/croco-cli/)
[![Last Commit](https://img.shields.io/github/last-commit/blnkoff/croco-cli.svg)](https://pypi.org/project/croco-cli/)
[![Development Status](https://img.shields.io/pypi/status/croco-cli)](https://pypi.org/project/croco-cli/)


The CLI for developing Web3-based projects in Croco Factory

- **[Telegram channel](https://t.me/crocofactory)**
- **[Bug reports](https://github.com/blnkoff/croco-cli/issues)**
- **[Quick Overview](#quick-overview)**

Project's source code is made available under the [MIT License](LICENSE)
           
# Quick Overview

Command `croco` display this in your console. 

<img alt="Console View" width="300" src="https://i.ibb.co/j4gxhRX/Screenshot-2024-05-17-at-19-17-46.png">

Let`s learn them:

- `change` - if you already have set multiple accounts, using `set` you can change current
- `export` - Export cli configuration
- `import` - Import cli configuration
- `init` - if you created you project or pacakge just now, you can initialize it, using template structure
- `install` - install Croco Factory packages. If package is placed in private GitHub repository, you need to have access 
              token with permission of downloading this package
- `reset` - reset some configured by user accounts
- `set` - set specified accounts, like digital wallets etc.
- `user` - show specified user accounts.

You can see more details using `--help` option with each command.

==> croco_cli-0.3.1.tar.gz: croco_cli-0.3.1/README.md <==
# croco-cli

[![Croco Logo](https://i.ibb.co/G5Pjt6M/logo.png)](https://t.me/crocofactory) 

[![PyPi version](https://img.shields.io/pypi/v/croco-cli)](https://pypi.org/project/croco-cli/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/croco-cli)](https://pypi.org/project/croco-cli/)
[![License](https://img.shields.io/github/license/blnkoff/croco-cli.svg)](https://pypi.org/project/croco-cli/)
[![Last Commit](https://img.shields.io/github/last-commit/blnkoff/croco-cli.svg)](https://pypi.org/project/croco-cli/)
[![Development Status](https://img.shields.io/pypi/status/croco-cli)](https://pypi.org/project/croco-cli/)


The CLI for developing Web3-based projects in Croco Factory

- **[Telegram channel](https://t.me/crocofactory)**
- **[Bug reports](https://github.com/blnkoff/croco-cli/issues)**
- **[Quick Overview](#quick-overview)**

Project's source code is made available under the [MIT License](LICENSE)
           
# Quick Overview

Command `croco` display this in your console. 

<img alt="Console View" width="300" src="https://i.ibb.co/j4gxhRX/Screenshot-2024-05-17-at-19-17-46.png">

Let`s learn them:

- `change` - if you already have set multiple accounts, using `set` you can change current
- `export` - export cli configuration
- `import` - import cli configuration
- `init` - if you created you project or pacakge just now, you can initialize it, using template structure
- `install` - install Croco Factory packages. If package is placed in private GitHub repository, you need to have access 
              token with permission of downloading this package
- `reset` - reset some configured by user accounts
- `set` - set specified accounts, like digital wallets etc.
- `user` - show specified user accounts.

You can see more details using `--help` option with each command.
